summaryrefslogtreecommitdiff
path: root/src/libcamera/camera.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/libcamera/camera.cpp')
-rw-r--r--src/libcamera/camera.cpp16
1 files changed, 15 insertions, 1 deletions
diff --git a/src/libcamera/camera.cpp b/src/libcamera/camera.cpp
index 44f2d71b..63b1f772 100644
--- a/src/libcamera/camera.cpp
+++ b/src/libcamera/camera.cpp
@@ -652,7 +652,8 @@ int Camera::release()
/**
* \brief Retrieve the list of controls supported by the camera
*
* Camera controls remain constant through the lifetime of the camera.
*
* \context This function is \threadsafe.
*
@@ -664,6 +665,19 @@ const ControlInfoMap &Camera::controls()
}
/**
+ * \brief Retrieve the list of properties of the camera
+ *
+ * Camera properties are static information that describe the capabilities of
+ * the camera. They remain constant through the lifetime of the Camera object.
+ *
+ * \return A ControlList of properties supported by the camera
+ */
+const ControlList &Camera::properties()
+{
+ return p_->pipe_->properties(this);
+}
+
+/**
* \brief Retrieve all the camera's stream information
*
* Retrieve all of the camera's static stream information. The static
@@ -652,7 +652,8 @@ int Camera::release()
* \brief Retrieve the list of controls supported by the camera
*
- * Camera controls remain constant through the lifetime of the camera.
+ * The list of controls supported by the camera and their associated
+ * constraints remain constant through the lifetime of the Camera object.
*
* \context This function is \threadsafe.